<?php
/**
 * A debug output class for the console (e.g. hub software)
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class DebugConsoleOutput extends BaseFrameworkSystem implements Debugger, OutputStreamer, Registerable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$debugInstance	The prepared debug instance
	 */
	public static final function createDebugConsoleOutput () {
		// Get a new instance
		$debugInstance = new DebugConsoleOutput();

		// Return it
		return $debugInstance;
	}

	/**
	 * Outputs the given data without HTML tags
	 *
	 * @param	$output		The HTML'ed output
	 * @param	$stripTags	Whether HTML tags shall be stripped out
	 * @return	void
	 */
	public final function outputStream ($output, $stripTags = FALSE) {
		// Strip HTML tags out?
		if ($stripTags === TRUE) {
			// Prepare the output without HTML tags
			$output = trim(html_entity_decode(strip_tags(stripslashes($output))));
		} else {
			// Prepare the output with HTML tags
			$output = trim(stripslashes($output));
		}

		// Are debug times enabled?
		if ($this->getConfigInstance()->getConfigEntry('debug_output_timings') == 'Y') {
			// Output it first
			$output = $this->getPrintableExecutionTime() . $output;
		} // END - if

		// And print it out...
		printf('%s%s', $output, chr(10));
	}

	/**
	 * Output the code
	 *
	 * @param	$outStream	Stream to output
	 * @param	$stripTags	Whether HTML tags shall be stripped out
	 * @return	void
	 */
	public final function output ($outStream = FALSE, $stripTags = FALSE) {
		// Empty output will be silently ignored
		if ($outStream !== FALSE) {
			$this->outputStream($outStream, $stripTags);
		} // END - if
	}

	/**
	 * Streams the data and maybe does something to it
	 *
	 * @param	$data	The data (string mostly) to "stream"
	 * @return	$data	The data (string mostly) to "stream"
	 * @throws	UnsupportedOperationException	If this method is called
	 */
	public function streamData ($data) {
		self::createDebugInstance(__CLASS__)->debugOutput('Unhandled ' . strlen($data) . ' bytes in this stream.');
		throw new UnsupportedOperationException(array($this, __FUNCTION__), self::EXCEPTION_UNSPPORTED_OPERATION);
	}

	/**
	 * Determines seek position
	 *
	 * @return	$seekPosition	Current seek position
	 * @throws	UnsupportedOperationException	If this method is called
	 */
	public function determineSeekPosition () {
		throw new UnsupportedOperationException(array($this, __FUNCTION__), self::EXCEPTION_UNSPPORTED_OPERATION);
	}

	/**
	 * Seek to given offset (default) or other possibilities as fseek() gives.
	 *
	 * @param	$offset		Offset to seek to (or used as "base" for other seeks)
	 * @param	$whence		Added to offset (default: only use offset to seek to)
	 * @return	$status		Status of file seek: 0 = success, -1 = failed
	 * @throws	UnsupportedOperationException	If this method is called
	 */
	public function seek ($offset, $whence = SEEK_SET) {
		self::createDebugInstance(__CLASS__)->debugOutput('offset=' . $offset . ',whence=' . $whence);
		throw new UnsupportedOperationException(array($this, __FUNCTION__), self::EXCEPTION_UNSPPORTED_OPERATION);
	}

	/**
	 * Size of file stack
	 *
	 * @return	$size	Size (in bytes) of file
	 * @throws	UnsupportedOperationException	If this method is called
	 */
	public function size () {
		throw new UnsupportedOperationException(array($this, __FUNCTION__), self::EXCEPTION_UNSPPORTED_OPERATION);
	}
}

// [EOF]
?>
